@@ -275,8 +275,9 @@ struct ast_channel {
 	/*! Current active data generator */
 	struct ast_generator *generator;
 
-	/*! Who are we bridged to, if we're bridged  Do not access directly,
-	    use ast_bridged_channel(chan) */
+	/*! Who are we bridged to, if we're bridged. Who is proxying for us,
+	  if we are proxied (i.e. chan_agent).
+	  Do not access directly, use ast_bridged_channel(chan) */
 	struct ast_channel *_bridge;
 	/*! Channel that will masquerade as us */
 	struct ast_channel *masq;		
@@ -469,6 +470,7 @@ struct chanmon;
 	oh.priority = priority; \
 	oh.cid_num = cid_num; \
 	oh.cid_name = cid_name; \
+	oh.account = account; \
 	oh.vars = vars; \
 	oh.parent_channel = NULL; \
 } 
@@ -479,6 +481,7 @@ struct outgoing_helper {
 	int priority;
 	const char *cid_num;
 	const char *cid_name;
+	const char *account;
 	struct ast_variable *vars;
 	struct ast_channel *parent_channel;
 };
